--
-- Copyright (c) 2005 Pandemic Studios, LLC. All rights reserved.
--

-- load the gametype script
Conquest = ScriptCB_DoFile("ObjectiveOneFlagCTF")
ScriptCB_DoFile("setup_teams") 

	--  REP Attacking (attacker is always #1)
    REP = 1;
    CIS = 2;
    --  These variables do not change
    ATT = REP;
    DEF = CIS;


function ScriptPostLoad()

	SoundEvent_SetupTeams( REP, 'rep', CIS, 'cis' )
    
    ctf = ObjectiveOneFlagCTF:New{teamATT = REP, teamDEF = CIS,
                           textATT = "game.modes.1flag", textDEF = "game.modes.1flag2",
                           captureLimit = 5, flag = "flag", flagIcon = "flag_icon", 
                           flagIconScale = 3.0, homeRegion = "homeregion",
                           captureRegionATT = "team1_capture", captureRegionDEF = "team2_capture",
                           capRegionMarkerATT = "hud_objective_icon_circle", capRegionMarkerDEF = "hud_objective_icon_circle",
                           capRegionMarkerScaleATT = 3.0, capRegionMarkerScaleDEF = 3.0, multiplayerRules = true}

    ctf:Start()    
    --
    EnableSPHeroRules()

--displays message when human player spawns as CIS
OnCharacterSpawn(
	function(player) 
		if IsCharacterHuman(player) then
			ShowMessageText( "message.spawn.human", DEF )
			ShowMessageText( "message.spawn.wrong", ATT )
		end
	end
)


--This contains two examples of an elevator.  If the bigger elevator stops working, walk away from it to get out of its regions, then walk back.  


---------------------
---Simple Elevator---
---------------------

--r1 and r2 are regions for the simple elevator.
--r1 moves the elevator up when a human enters it.
--r2 moves the elevator down when a human enters it.

ActivateRegion("r1")
ActivateRegion("r2")

region1 = OnEnterRegion(
		function(region, player)
			if IsCharacterHuman(player) then
				
				ShowMessageText( "message.elevator.simple.up", DEF )

				--make sure r2 isn't using the elevator object.
				PauseAnimation("elevator2_down")

				--move the elevator up, making sure it starts from the bottom.
				RewindAnimation("elevator2_up")
				PlayAnimation("elevator2_up")				
			end
		end, 
		"r1"
	)

region2 = OnEnterRegion(
		function(region, player)
			if IsCharacterHuman(player) then
				ShowMessageText( "message.elevator.simple.down", DEF )
				
				--make sure r1 isn't using the elevator object.
				PauseAnimation("elevator2_up")

				--move the elevator down, making sure it starts from the top.
				RewindAnimation("elevator2_down")
				PlayAnimation("elevator2_down")
			end
		end, 
		"r2"
	)



-------------------------------
---More Complicated Elevator---
-------------------------------

--elv1_r1 (r1):used to determine when the player is standing on the elevator so it can move up.
--elv1_r2 (r2):used to determine when the player is standing on the elevator so it can move down.
--elv1_r3 (r3):used to determine when the player is about to go on the elevator to go up.  Calls the elevator if it is not at the bottom near the player.
--elv1_r4 (r4):used to determine when the player is about to go on the elevator to go down.  Calls the elevator if it is not at the top near the player.
--elv1_r5 (r5):used to determine when the elevator reaches the bottom with a player riding it.
--elv1_r5_b (r5_b):used to determine if the player fell off the elevator when riding it to the top.
--elv1_r6 (r6):used to determine when the elevator reaches the top with a player riding it.
--elv1_r6_b (r6_b):used to determine if the player fell off the elevator when riding it to the bottom.

--activate/deactive regions used/unsued.
--1 for activate, anything else for deactivate.
regions = function( a, b, c, d, e, f )
	if a == 1 then
		ActivateRegion("elv1_r1")
	else
		DeactivateRegion("elv1_r1")
	end

	if b == 1 then
		ActivateRegion("elv1_r2")
	else
		DeactivateRegion("elv1_r2")
	end

	if c == 1 then
		ActivateRegion("elv1_r3")
	else
		DeactivateRegion("elv1_r3")
	end

	if d == 1 then
		ActivateRegion("elv1_r4")
	else
		DeactivateRegion("elv1_r4")
	end

	if e == 1 then
		ActivateRegion("elv1_r5")
		ActivateRegion("elv1_r5_b")
	else
		DeactivateRegion("elv1_r5")
		DeactivateRegion("elv1_r5_b")
	end

	if f == 1 then
		ActivateRegion("elv1_r6")
		ActivateRegion("elv1_r6_b")
	else
		DeactivateRegion("elv1_r6")
		DeactivateRegion("elv1_r6_b")
	end	
end

--activate elevator waiting areas
regions( 0, 0, 1, 1, 0, 0 )

--1 for elevator moving down, 2 for elevator moving up
location = 1

R1 = OnEnterRegion(
	function(region, player)
		if IsCharacterHuman(player) then

			--activate/deactive regions used/unsued.
			regions( 0, 0, 0, 0, 0, 1 )

			--if elevator is moving down or at the bottom.
			if location == 1 then

				--make the elevator object isn't in use by another animation.
				PauseAnimation("elevator1_down")


				--move the elevator up, making sure it starts from the bottom.
				RewindAnimation("elevator1_up")
				PlayAnimation("elevator1_UP")

				ShowMessageText( "message.elevator.up", DEF )				

				--elevator now moving up, so set location to 2
				location = 2
			end
		end
	end,
	"elv1_r1"
)

--the rest of the added code is almost the same, just with different regions being activated/deactivated.  I will not comment it.


R2 = OnEnterRegion(
	function(region, player)
		if IsCharacterHuman(player) then

			regions( 0, 0, 0, 0, 1, 0 )

			if location == 2 then
				PauseAnimation("elevator1_up")
				RewindAnimation("elevator1_down")
				PlayAnimation("elevator1_down")

				ShowMessageText( "message.elevator.down", DEF )

				location = 1
			end
		end
	end,
	"elv1_r2"
)

R3 = OnEnterRegion(
	function(region, player)
		if IsCharacterHuman(player) then

			regions( 1, 0, 0, 0, 0, 0 )

			ShowMessageText( "message.elevator.calling", DEF )

			if location == 2 then
				PauseAnimation("elevator1_up")
				RewindAnimation("elevator1_down")
				PlayAnimation("elevator1_down")

				ShowMessageText( "message.elevator.down", DEF )

				location = 1
			end
		end
	end,
	"elv1_r3"
)

R4 = OnEnterRegion(
	function(region, player)
		if IsCharacterHuman(player) then

			regions( 0, 1, 0, 0, 0, 0 )

			ShowMessageText( "message.elevator.calling", DEF )

			if location == 1 then
				PauseAnimation("elevator1_down")
				RewindAnimation("elevator1_up")
				PlayAnimation("elevator1_UP")
	
				ShowMessageText( "message.elevator.up", DEF )

				location = 2
			end
		end
	end,
	"elv1_r4"
)

R5 = OnEnterRegion(
	function(region, player)
		if IsCharacterHuman(player) then

			regions( 0, 0, 1, 1, 0, 0 )

			ShowMessageText( "message.elevator.getoff", DEF )
		end
	end,
	"elv1_r5"
)

R5b = OnEnterRegion(
	function(region, player)
		if IsCharacterHuman(player) then

			regions( 0, 0, 1, 1, 0, 0 )

			ShowMessageText( "message.elevator.getoff", DEF )
		end		
	end,
	"elv1_r5_b"
)

R6 = OnEnterRegion(
	function(region, player)
		if IsCharacterHuman(player) then

			regions( 0, 0, 1, 1, 0, 0 )

			ShowMessageText( "message.elevator.getoff", DEF )
		end
	end,
	"elv1_r6"
)

R6b = OnEnterRegion(
	function(region, player)
		if IsCharacterHuman(player) then

			regions( 0, 0, 1, 1, 0, 0 )

			ShowMessageText( "message.elevator.getoff", DEF )
		end
	end,
	"elv1_r6_b"
)

 end

---------------------------------------------------------------------------
-- FUNCTION:    ScriptInit
-- PURPOSE:     This function is only run once
-- INPUT:
-- OUTPUT:
-- NOTES:       The name, 'ScriptInit' is a chosen convention, and each
--              mission script must contain a version of this function, as
--              it is called from C to start the mission.
---------------------------------------------------------------------------
function ScriptInit()
    
    ReadDataFile("ingame.lvl")
    
   
    SetMaxFlyHeight(200)
    SetMaxPlayerFlyHeight (200)
    
    SetMemoryPoolSize ("ClothData",20)
    SetMemoryPoolSize ("Combo",50)              -- should be ~ 2x number of jedi classes
    SetMemoryPoolSize ("Combo::State",650)      -- should be ~12x #Combo
    SetMemoryPoolSize ("Combo::Transition",650) -- should be a bit bigger than #Combo::State
    SetMemoryPoolSize ("Combo::Condition",650)  -- should be a bit bigger than #Combo::State
    SetMemoryPoolSize ("Combo::Attack",550)     -- should be ~8-12x #Combo
    SetMemoryPoolSize ("Combo::DamageSample",6000)  -- should be ~8-12x #Combo::Attack
    SetMemoryPoolSize ("Combo::Deflect",100)     -- should be ~1x #combo  
    
    ReadDataFile("sound\\yav.lvl;yav1cw")
    ReadDataFile("SIDE\\rep.lvl",
                             "rep_inf_ep3_rifleman",
                             "rep_inf_ep3_rocketeer",
                             "rep_inf_ep3_engineer",
                             "rep_inf_ep3_sniper",
                             "rep_inf_ep3_officer",
                             "rep_inf_ep3_jettrooper",
                             "rep_hover_fightertank",
                             "rep_hero_anakin",
                             "rep_hover_barcspeeder")
    ReadDataFile("SIDE\\cis.lvl",
                             "cis_inf_rifleman",
                             "cis_inf_rocketeer",
                             "cis_inf_engineer",
                             "cis_inf_sniper",
                             "cis_inf_officer",
                             "cis_inf_droideka",
                             "cis_hero_darthmaul",
                             "cis_hover_aat")
                             

    ReadDataFile("SIDE\\tur.lvl", 
    			"tur_bldg_laser",
    			"tur_bldg_tower")          
                             
	SetupTeams{
		rep = {
			team = REP,
			units = 20,
			reinforcements = 150,
			soldier  = { "rep_inf_ep3_rifleman",9, 25},
			assault  = { "rep_inf_ep3_rocketeer",1, 4},
			engineer = { "rep_inf_ep3_engineer",1, 4},
			sniper   = { "rep_inf_ep3_sniper",1, 4},
			officer = {"rep_inf_ep3_officer",1, 4},
			special = { "rep_inf_ep3_jettrooper",1, 4},
	        
		},
		cis = {
			team = CIS,
			units = 20,
			reinforcements = 150,
			soldier  = { "cis_inf_rifleman",9, 25},
			assault  = { "cis_inf_rocketeer",1, 4},
			engineer = { "cis_inf_engineer",1, 4},
			sniper   = { "cis_inf_sniper",1, 4},
			officer = {"cis_inf_officer",1, 4},
			special = { "cis_inf_droideka",1, 4},
		}
	}
     
    SetHeroClass(CIS, "cis_hero_darthmaul")
    SetHeroClass(REP, "rep_hero_anakin")
   

    --  Level Stats
    --  ClearWalkers()
    AddWalkerType(0, 4) -- special -> droidekas
    AddWalkerType(1, 0) -- 1x2 (1 pair of legs)
    AddWalkerType(2, 0) -- 2x2 (2 pairs of legs)
    AddWalkerType(3, 0) -- 3x2 (3 pairs of legs)
    local weaponCnt = 1024
    SetMemoryPoolSize("Aimer", 75)
    SetMemoryPoolSize("AmmoCounter", weaponCnt)
    SetMemoryPoolSize("BaseHint", 1024)
    SetMemoryPoolSize("EnergyBar", weaponCnt)
	SetMemoryPoolSize("EntityCloth", 32)
	SetMemoryPoolSize("EntityFlyer", 32)
    SetMemoryPoolSize("EntityHover", 32)
    SetMemoryPoolSize("EntityLight", 200)
    SetMemoryPoolSize("EntitySoundStream", 4)
    SetMemoryPoolSize("EntitySoundStatic", 32)
    SetMemoryPoolSize("MountedTurret", 32)
	SetMemoryPoolSize("Navigator", 128)
    SetMemoryPoolSize("Obstacle", 1024)
	SetMemoryPoolSize("PathNode", 1024)
    SetMemoryPoolSize("SoundSpaceRegion", 64)
    SetMemoryPoolSize("TreeGridStack", 1024)
	SetMemoryPoolSize("UnitAgent", 128)
	SetMemoryPoolSize("UnitController", 128)
	SetMemoryPoolSize("Weapon", weaponCnt)
	SetMemoryPoolSize("FlagItem", 1)
    
    SetSpawnDelay(10.0, 0.25)
    --ReadDataFile("dc:PCE\\PCE.lvl", "PCE_conquest")
    ReadDataFile("dc:PCE\\PCE.lvl", "PCE_1flag")
    SetDenseEnvironment("false")




    --  Sound
    
    SetSoundEffect("ScopeDisplayZoomIn",  "binocularzoomin")
    SetSoundEffect("ScopeDisplayZoomOut", "binocularzoomout")

    voiceSlow = OpenAudioStream("sound\\global.lvl", "rep_unit_vo_slow")
    AudioStreamAppendSegments("sound\\global.lvl", "cis_unit_vo_slow", voiceSlow)
    AudioStreamAppendSegments("sound\\global.lvl", "global_vo_slow", voiceSlow)
    
    voiceQuick = OpenAudioStream("sound\\global.lvl", "rep_unit_vo_quick")
    AudioStreamAppendSegments("sound\\global.lvl", "cis_unit_vo_quick", voiceQuick)
    
    OpenAudioStream("sound\\global.lvl",  "cw_music")
    -- OpenAudioStream("sound\\global.lvl",  "global_vo_quick")
    -- OpenAudioStream("sound\\global.lvl",  "global_vo_slow")
    OpenAudioStream("sound\\yav.lvl",  "yav1")
    OpenAudioStream("sound\\yav.lvl",  "yav1")
    OpenAudioStream("sound\\yav.lvl",  "yav1_emt")

    SetBleedingVoiceOver(REP, REP, "rep_off_com_report_us_overwhelmed", 1)
    SetBleedingVoiceOver(REP, CIS, "rep_off_com_report_enemy_losing",   1)
    SetBleedingVoiceOver(CIS, REP, "cis_off_com_report_enemy_losing",   1)
    SetBleedingVoiceOver(CIS, CIS, "cis_off_com_report_us_overwhelmed", 1)

    SetOutOfBoundsVoiceOver(2, "cisleaving")
    SetOutOfBoundsVoiceOver(1, "repleaving")

    SetAmbientMusic(REP, 1.0, "rep_yav_amb_start",  0,1)
    SetAmbientMusic(REP, 0.8, "rep_yav_amb_middle", 1,1)
    SetAmbientMusic(REP, 0.2, "rep_yav_amb_end",    2,1)
    SetAmbientMusic(CIS, 1.0, "cis_yav_amb_start",  0,1)
    SetAmbientMusic(CIS, 0.8, "cis_yav_amb_middle", 1,1)
    SetAmbientMusic(CIS, 0.2, "cis_yav_amb_end",    2,1)

    SetVictoryMusic(REP, "rep_yav_amb_victory")
    SetDefeatMusic (REP, "rep_yav_amb_defeat")
    SetVictoryMusic(CIS, "cis_yav_amb_victory")
    SetDefeatMusic (CIS, "cis_yav_amb_defeat")

    SetSoundEffect("ScopeDisplayZoomIn",      "binocularzoomin")
    SetSoundEffect("ScopeDisplayZoomOut",     "binocularzoomout")
    --SetSoundEffect("BirdScatter",             "birdsFlySeq1")
    --SetSoundEffect("WeaponUnableSelect",      "com_weap_inf_weaponchange_null")
    --SetSoundEffect("WeaponModeUnableSelect",  "com_weap_inf_modechange_null")
    SetSoundEffect("SpawnDisplayUnitChange",       "shell_select_unit")
    SetSoundEffect("SpawnDisplayUnitAccept",       "shell_menu_enter")
    SetSoundEffect("SpawnDisplaySpawnPointChange", "shell_select_change")
    SetSoundEffect("SpawnDisplaySpawnPointAccept", "shell_menu_enter")
    SetSoundEffect("SpawnDisplayBack",             "shell_menu_exit")


--OpeningSateliteShot
    AddCameraShot(0.908386, -0.209095, -0.352873, -0.081226, -45.922508, -19.114113, 77.022636);

    AddCameraShot(-0.481173, 0.024248, -0.875181, -0.044103, 14.767292, -30.602322, -144.506851);
    AddCameraShot(0.999914, -0.012495, -0.004416, -0.000055, 1.143253, -33.602314, -76.884430);
    AddCameraShot(0.839161, 0.012048, -0.543698, 0.007806, 19.152437, -49.802273, 24.337317);
    AddCameraShot(0.467324, 0.006709, -0.883972, 0.012691, 11.825212, -49.802273, -7.000720);
    AddCameraShot(0.861797, 0.001786, -0.507253, 0.001051, -11.986043, -59.702248, 23.263165);
    AddCameraShot(0.628546, -0.042609, -0.774831, -0.052525, 20.429928, -48.302277, 9.771714);
    AddCameraShot(0.765213, -0.051873, 0.640215, 0.043400, 57.692474, -48.302277, 16.540724);
    AddCameraShot(0.264032, -0.015285, -0.962782, -0.055734, -16.681797, -42.902290, 129.553268);
    AddCameraShot(-0.382320, 0.022132, -0.922222, -0.053386, 20.670977, -42.902290, 135.513001);
end

